=====================
KIE Server Python SDK
=====================


.. image:: https://img.shields.io/pypi/v/kie_server_py.svg
        :target: https://pypi.python.org/pypi/kie_server_py

.. image:: https://img.shields.io/travis/aman0408/kie_server_py.svg
        :target: https://travis-ci.com/aman0408/kie_server_py

.. image:: https://readthedocs.org/projects/kie-server-py/badge/?version=latest
        :target: https://kie-server-py.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Python Boilerplate contains all the boilerplate you need to create a Python package.


* Free software: MIT license
* Documentation: https://kie-server-py.readthedocs.io.


Features
--------

* Execute DMN on KIE Server backed by Drools

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
